@@ -519,7 +519,7 @@ class RestAPI(object):
 				data["requests"]["rate"] = 0
 
 			# check rate limit.
-			if not success and int(data["requests"]) <= self.__plans__[plan]["rate_limit"]: 
+			if not success and int(data["requests"]["rate"]) <= self.__plans__[plan]["rate_limit"]: 
 				success = True
 
 		# response.
